/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2025 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system                           *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.20.0.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for LPC1758 (KEIL MCB1700) eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define FIO_BASE_ADDR              (0x2009C000u)
#define FIO1DIR3                   (*(volatile unsigned char *)(FIO_BASE_ADDR + 0x23u))
#define FIO2DIR0                   (*(volatile unsigned char *)(FIO_BASE_ADDR + 0x40u))
#define FIO1SET3                   (*(volatile unsigned char *)(FIO_BASE_ADDR + 0x3Bu))
#define FIO2SET0                   (*(volatile unsigned char *)(FIO_BASE_ADDR + 0x58u))
#define FIO1CLR3                   (*(volatile unsigned char *)(FIO_BASE_ADDR + 0x3Fu))
#define FIO2CLR0                   (*(volatile unsigned char *)(FIO_BASE_ADDR + 0x5Cu))
#define FIO1PIN3                   (*(volatile unsigned char *)(FIO_BASE_ADDR + 0x37u))
#define FIO2PIN0                   (*(volatile unsigned char *)(FIO_BASE_ADDR + 0x54u))

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/
static const char _aLed[] = {4u, 5u, 7u, 2u, 3u, 4u, 5u, 6u};  // LED bit positions for P1 and P2

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  FIO1DIR3 |= 0u
              | (1u << 4u)
              | (1u << 5u)
              | (1u << 7u)
              ;
  FIO2DIR0 |= 0u
              | (1u << 2u)
              | (1u << 3u)
              | (1u << 4u)
              | (1u << 5u)
              | (1u << 6u)
              ;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index > 2) {
    FIO2SET0 = (1u << _aLed[Index]);   // Switch on LED
  } else {
    FIO1SET3 = (1u << _aLed[Index]);   // Switch on LED
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index > 2) {
    FIO2CLR0 = (1u << _aLed[Index]);   // Switch on LED
  } else {
    FIO1CLR3 = (1u << _aLed[Index]);   // Switch off LED
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index > 2) {
    FIO2PIN0 ^= (1u << _aLed[Index]);  // Toggle LED
  } else {
    FIO1PIN3 ^= (1u << _aLed[Index]);  // Toggle LED
  }
}

/****** End Of File *************************************************/
